@@ -24,20 +24,25 @@
 // ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 // (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 // SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
+/* exported main */
 
 pkg.initGettext();
 pkg.initFormat();
-pkg.require({ 'Gdk': '3.0',
-              'GdkPixbuf': '2.0',
-              'GLib': '2.0',
-              'GObject': '2.0',
-              'Gtk': '3.0',
-              'Gst': '1.0',
-              'GstAudio': '1.0',
-              'GstPbutils': '1.0' });
+pkg.require({
+    'Gdk': '3.0',
+    'GdkPixbuf': '2.0',
+    'GLib': '2.0',
+    'GObject': '2.0',
+    'Gtk': '3.0',
+    'Gst': '1.0',
+    'GstAudio': '1.0',
+    'GstPlayer': '1.0',
+    'GstPbutils': '1.0',
+    'Handy': '1',
+});
 
-const Application = imports.application;
+const { Application } = imports.application;
 
 function main(argv) {
-    return (new Application.Application()).run(argv);
+    return new Application().run(argv);
 }
